==> openflowplugin-extension-nicira-0.7.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/src/choice/grouping/src/choice/SrcOfIpDstCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.src.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link SrcOfIpDstCaseBuilder} instances.
 *
 * @see SrcOfIpDstCaseBuilder
 *
 */
public class SrcOfIpDstCaseBuilder implements Builder<SrcOfIpDstCase> {

    private Boolean _ofIpDst;


    Map<Class<? extends Augmentation<SrcOfIpDstCase>>, Augmentation<SrcOfIpDstCase>> augmentation = Collections.emptyMap();

    public SrcOfIpDstCaseBuilder() {
    }
    public SrcOfIpDstCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpDstGrouping arg) {
        this._ofIpDst = arg.isOfIpDst();
    }

    public SrcOfIpDstCaseBuilder(SrcOfIpDstCase base) {
        this._ofIpDst = base.isOfIpDst();
        if (base instanceof SrcOfIpDstCaseImpl) {
            SrcOfIpDstCaseImpl impl = (SrcOfIpDstCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<SrcOfIpDstCase>>, Augmentation<SrcOfIpDstCase>> aug =((AugmentationHolder<SrcOfIpDstCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpDstGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpDstGrouping) {
            this._ofIpDst = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpDstGrouping)arg).isOfIpDst();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpDstGrouping]");
    }

    public Boolean isOfIpDst() {
        return _ofIpDst;
    }
    
    @SuppressWarnings("unchecked")
    public <E extends Augmentation<SrcOfIpDstCase>> E augmentation(Class<E> augmentationType) {
        return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public SrcOfIpDstCaseBuilder setOfIpDst(final Boolean value) {
        this._ofIpDst = value;
        return this;
    }
    
    public SrcOfIpDstCaseBuilder addAugmentation(Class<? extends Augmentation<SrcOfIpDstCase>> augmentationType, Augmentation<SrcOfIpDstCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public SrcOfIpDstCaseBuilder removeAugmentation(Class<? extends Augmentation<SrcOfIpDstCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public SrcOfIpDstCase build() {
        return new SrcOfIpDstCaseImpl(this);
    }

    private static final class SrcOfIpDstCaseImpl implements SrcOfIpDstCase {
    
        private final Boolean _ofIpDst;
    
        private Map<Class<? extends Augmentation<SrcOfIpDstCase>>, Augmentation<SrcOfIpDstCase>> augmentation = Collections.emptyMap();
    
        SrcOfIpDstCaseImpl(SrcOfIpDstCaseBuilder base) {
            this._ofIpDst = base.isOfIpDst();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<SrcOfIpDstCase> getImplementedInterface() {
            return SrcOfIpDstCase.class;
        }
    
        @Override
        public Boolean isOfIpDst() {
            return _ofIpDst;
        }
        
        @SuppressWarnings("unchecked")
        @Override
        public <E extends Augmentation<SrcOfIpDstCase>> E augmentation(Class<E> augmentationType) {
            return (E) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ofIpDst);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!SrcOfIpDstCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            SrcOfIpDstCase other = (SrcOfIpDstCase)obj;
            if (!Objects.equals(_ofIpDst, other.isOfIpDst())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                SrcOfIpDstCaseImpl otherImpl = (SrcOfIpDstCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<SrcOfIpDstCase>>, Augmentation<SrcOfIpDstCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("SrcOfIpDstCase");
            CodeHelpers.appendValue(helper, "_ofIpDst", _ofIpDst);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> openflowplugin-extension-nicira-0.7.3-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/openflowplugin/extension/nicira/action/rev140714/src/choice/grouping/src/choice/SrcOfIpDstCaseBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.src.choice.grouping.src.choice;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Boolean;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link SrcOfIpDstCaseBuilder} instances.
 *
 * @see SrcOfIpDstCaseBuilder
 *
 */
public class SrcOfIpDstCaseBuilder implements Builder<SrcOfIpDstCase> {

    private Boolean _ofIpDst;


    Map<Class<? extends Augmentation<SrcOfIpDstCase>>, Augmentation<SrcOfIpDstCase>> augmentation = Collections.emptyMap();

    public SrcOfIpDstCaseBuilder() {
    }
    public SrcOfIpDstCaseBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpDstGrouping arg) {
        this._ofIpDst = arg.isOfIpDst();
    }

    public SrcOfIpDstCaseBuilder(SrcOfIpDstCase base) {
        this._ofIpDst = base.isOfIpDst();
        if (base instanceof SrcOfIpDstCaseImpl) {
            SrcOfIpDstCaseImpl impl = (SrcOfIpDstCaseImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<SrcOfIpDstCase>>, Augmentation<SrcOfIpDstCase>> aug =((AugmentationHolder<SrcOfIpDstCase>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpDstGrouping</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpDstGrouping) {
            this._ofIpDst = ((org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpDstGrouping)arg).isOfIpDst();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.openflowplugin.extension.nicira.action.rev140714.NxmOfIpDstGrouping]");
    }

    public Boolean isOfIpDst() {
        return _ofIpDst;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<SrcOfIpDstCase>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public SrcOfIpDstCaseBuilder setOfIpDst(final Boolean value) {
        this._ofIpDst = value;
        return this;
    }
    
    public SrcOfIpDstCaseBuilder addAugmentation(Class<? extends Augmentation<SrcOfIpDstCase>> augmentationType, Augmentation<SrcOfIpDstCase> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public SrcOfIpDstCaseBuilder removeAugmentation(Class<? extends Augmentation<SrcOfIpDstCase>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public SrcOfIpDstCase build() {
        return new SrcOfIpDstCaseImpl(this);
    }

    private static final class SrcOfIpDstCaseImpl implements SrcOfIpDstCase {
    
        private final Boolean _ofIpDst;
    
        private Map<Class<? extends Augmentation<SrcOfIpDstCase>>, Augmentation<SrcOfIpDstCase>> augmentation = Collections.emptyMap();
    
        SrcOfIpDstCaseImpl(SrcOfIpDstCaseBuilder base) {
            this._ofIpDst = base.isOfIpDst();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<SrcOfIpDstCase> getImplementedInterface() {
            return SrcOfIpDstCase.class;
        }
    
        @Override
        public Boolean isOfIpDst() {
            return _ofIpDst;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<SrcOfIpDstCase>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_ofIpDst);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!SrcOfIpDstCase.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            SrcOfIpDstCase other = (SrcOfIpDstCase)obj;
            if (!Objects.equals(_ofIpDst, other.isOfIpDst())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                SrcOfIpDstCaseImpl otherImpl = (SrcOfIpDstCaseImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<SrcOfIpDstCase>>, Augmentation<SrcOfIpDstCase>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("SrcOfIpDstCase");
            CodeHelpers.appendValue(helper, "_ofIpDst", _ofIpDst);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}
